c"~~~~~~~~~~~~~~~  WIND-AND-WAVES ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~<hmk>
c for details see subroutine "ocean"  and "swell".
  1   write(*,*)
      do 2 i=1,50
      write(*,*)
  2   continue
      write(*,*)
     &' ~~~~~~~~~~~~~~~~~~  WIND-AND-WAVES  <v12>  ~~~~~~~~~~~~~~~~~ '
      write(*,*)
      write(*,*)
      write(*,*)'This program performs two types of calculations for'
      write(*,*)'wind, waves, distances, depths and currents:'
      write(*,*)'(Note: No guarantee whatsoever, use at own risk!)'
      write(*,*)
      write(*,*)
     & '[1]: Calculate Waveheight from Wind, Duration of Wind, Fetch,',
     & '     Depth of Water and Current'
      write(*,*)
      write(*,*)
     & '[2]: Calculate Speed and Distance of a Windfield ',
     $ '     from the Period and Height of the Swell'
      write(*,*)
      write(*,*)
      write(*,*) 'Now chose by entering  1  or  2  [or 0 for end]:'
      read(*,*) indx
      if(indx.eq.0) goto 999
      if(indx.gt.2) goto 1
      if(indx.eq.1) call ocean()
      if(indx.eq.2) call swell()
      if(0.eq.0) goto 1
  999 continue
      write(*,*) ' ~~~~~~ END of WIND-AND-WAVES ~~~~~~~~'
      stop
      end

ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine ocean()
c "oceanwaves: wave-heights, from wind-speed, including fetch    <hmk>
c     (((the program is identical to version v3-22 and was tested
c     successfully as v3-22test against CETN IV-9 and Seewetter)))
c.....................................................................
c
c     (internal units are: meters, seconds)
c
c === The Basic Model: Chapter 4, Figure 4.1 (originally by
c     Gren and Dorrestein 1976), from Document WMO-No.702 (1998): World
c     Meteorological Society, "Guide to Wave Analysis and Forecasting".
c
c     Shallow Water Effects and Currents: Chapter 4.5 of WMO-702, but
c     for currents in particular:
c     CETN IV-9 (6/97) Coastal Engineering Technical Note;
c     "One-dimensional wave-current interaction"; by Jan McKee Smith
c     US-Army Enegineering Waterways Experiment Station,
c     Coastal and Hydraulics Laboratory jm.smith@cerc.wes.army.mil
c
c === General Literature: Landau & Lifshitz,
c     "Hydrodynamics" (Theoretical Physics Textbook)
c
c     Book: Introduction to Physical Oceanography
c     by Robert H. Stewart
c     see: http://oceanworld.tamu.edu/resources/ocng_textbook/chapter16/
c                /chapter16_4.htm
c
c     Rayleigh-model for random heights; Pierson-Moskowitz-model;
c     JONSWAP-model for deep water; Bouws et al. TMA-spectrum (1995)
c     for shallow water with Kitaigorodski-factor   (from the web).
c
c     G.B. Whitham, Linear and Nonlinear Waves, Wiley 1974.
c
c     Jonsson, I.G. (1990) Wave-current interactions, in The Sea,
c     Le Mehaute and Hanes, John Wiley and Sons, NY, Chapter 7, 65-120.
c
c     Book: Seewetter, ISBN 3-88412-367-X, DSV-Verlag, Hamburg.
c
c     <hmk>-adjustments to match theory to observations,
c     approximately within 10 percent.
c
c     Basic scales:
c     : Height ~ Wind^2   {Bernoulli compensates gravity}
c     : Height^2 ~ fetch or ~ duration {energy increases ~ time}
c     : omeg-k*curr = sqrt(g k tanh[k depth]) {dispersion relation}
c
      dimension hem(100), hec(100), tim(100), rat(199), iseas(100)
      dimension mhrs(100), mr(100)
      character xcar
      common /com2/ velo,gg,deep
      pi=3.1415927
      pipi=2*pi
      g=9.81
      gg=g
      zwind=15
      zdura=200
      zfetch=5000
      zdepth=5000
      zcurr=0.
      
      itest=0
c
 19   continue
      model=1
cccccccccccccccccc" BEGIN INPUT" ccccccccccccccc
      do 2 i=1,50
      write(*,*)
 2    continue
c
       write(*,*)
     &' ~~~~~~~~~~~ Height of Ocean Waves ~~~~~~~~~~~~~~~~~~~~~~~~~~~ '
      write(*,*) ' '
      write(*,*)
     &'The program calculates wave-length, wave-height and periodicity'
      write(*,*)
     &'based on input-data for wind-speed, duration, fetch, depth and'
      write(*,*)
     &'current. -  Agreement typically within a few percent is'
      write(*,*)
     &'achieved with various results from publicly available'
      write(*,*)
     &'sources, e.g. US Army Coastal Engineering CETN IV-17, the'
      write(*,*)
     &'document WMO-Nr.702 of the World Meteorological Organisation,'
      write(*,*)
     &'or the book "Seewetter", ISBN 3-88412-367-X, but no guarantee'
      write(*,*)
     &'can be given.    <hmk>'
      write(*,*)
      write(*,*)
      write(*,*) '[hit ENTER to continue]...'
      read(*,*)
      
      do 16 ih=1,50
        write(*,*)
 16   continue
      write(*,*)
     &' ~~~~~ Details of the model: ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ '
      write(*,*)
     &'The program is based on hydrodynamic and oceanographic'
      write(*,*)
     &'theory, such as Rayleigh-, Pierson-Moskowitz-, JONSWAP-'
      write(*,*)
     &'Models for the deep-water calculations, and has been'
      write(*,*)
     &'adjusted to match experimental observations. - The shallow-'
      write(*,*)
     &'water and the current calculations assume, that wind-sea'
      write(*,*)
     &'is generated in deep water without current, the waves then'
      write(*,*)
     &'approaching an area with shallow water and/or current.'
      write(*,*)
     &'This holds typically for coastal tidal currents, or sudden'
      write(*,*)
     &'reductions of depth in coastal waters. - '
      write(*,*)
     &'(For large areas of reduced depth like the baltic sea this '
      write(*,*)
     &'model may somewhat overestimate the wave height)'
      write(*,*)
     &'[ To be used as an estimate only, not safe for navigation ! ]'
      write(*,*)
     &' ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ '
  1   continue
      write(*,*) '~~~ [enter  0   to return to main menu] ~~~'
      write(*,*) ' '
      write(*,*) 'Input> Wind-speed in knots, Range:{1,65}='
      ibft=0.
      call readit(zwind)
      wind=zwind
      if(wind.lt.-0.5) model=0
      wind=abs(wind)
      if(wind.le.0.01) goto 999
      if(wind.lt.1.) wind=1.
      if(wind.gt.65) then
      wind=65.+10.*alog(wind/65.)
      write(*,*)
      write(*,*)' NOTE: Results for winds above 65 knots are not '
      write(*,*)' reliable, as these winds will take off the tops'
      write(*,*)' of the waves.        Therefore:'
      write(*,*)' Waveheights will be actually LOWER than calculated!'
      write(*,*)
      endif
      
      if(wind.gt.70.) wind=70.
      zwind=wind
      ibft=0.726*wind**0.665 +0.5
      v=wind*1852./3600.
      t0=pipi * v/g
      r0=pipi * v**2/g
      write(*,*) 'Input> Duration of wind in hours, Range:{1,200} ='
      call readit(zdura)
      dura=zdura
      if(dura.gt.200) dura=200
      if(dura.lt.1) dura=1
      zdura=dura
      write(*,*) 'Input> Fetch in  km, Range:{1,5000} ='
      call readit(zfetch)
      fetch=zfetch
      if(fetch.gt.5000) fetch=5000
      if(fetch.lt.1.) fetch=1.
      fec=fetch/1000.
      zfetch=fetch
      
      if(itest.gt.1) goto  10

      write(*,*) 'Input> Depth of water in meters, Range:{1,5000} ='
      call readit(zdepth)
      depth=zdepth
      if(depth.gt.5000) depth=5000
      if(depth.lt.1.) depth=1.
      deep=depth
      zdepth=depth
      write(*,*) 'Input> Current of water in knots, Range:{-15,15} ='
      write(*,*) '       (negative value: current against the wind)'
      call readit(zcurr)
      curr=zcurr
      if(curr.gt.1000) curr=0.
      if(curr.gt.15) curr=15
      if(curr.lt.-15) curr=-15.
      zcurr=curr
      velo=curr*1852./3600.

cccccccccccccccccc" END INPUT" ccccccccccccccc

 10   continue
      do 17 i=1,50
      write(*,*)
 17   continue
      call myname(wind,dura,fetch)
      write(*,*)' ~~~~~~~~~~~~~~ Height of Ocean Waves ~~~~~~~~~~~~~~~ '
c
c- "deep water analysis without current
      call deepw(wind,dura,fetch,hsinf,ht0,hf0,hs00,tper00,wlen00)
      hs0=hs00
      tper0=tper00
      wlen0=wlen00

c- "correction of wave-height and length for current in deep water"
      winc=abs(wind-curr)
      call deepw(winc,dura,fetch,hsinfc,ht0c,hf0c,hs0c,tper0c,wlen0c)
c     now this waveheight  hs0c corresponds to the relative wind in
c     deep water, and also the frequency tper0c    "<NOT USED>

c "evaluation of wave-height and length via dispersion relations
      call curwav(g,depth,curr,tper0,hs0,hs2,wlen2,brk,ier)

c "selection of display depending on model=0,1:
      if(model.eq.0) then
       hs2=hs0c
       wlen2=wlen0c
       tper2=tper0c
c       write(*,*) '           [model: wind relative to current]'
      else
       tper2=tper0
c       write(*,*) '  [model: incoming ocean waves & tidal current]'
      endif

c- "steepness
      stp0= hs0 /wlen0
      stp2= hs2 /wlen2
      ss0=stp2/stp0
      if(ier.gt.1) wlen2=4999.
c- "u_max= - g / (4 omeg) = -g * Tper / (8 Pi)
      umax=-tper2*g/(8*pi)*(3600./1852.)

      write(*,*)' Bft:   Wind:    Time:   Fetch:   Depth:  Current:'
      write(6,911) ibft, wind, dura, fetch, depth, curr
      write(*,*) ' '
      write(*,*) ' Characteristic Wave Height Hc, Length Lc, Period Tc:'
      write(6,910) hs2, wlen2, tper2
      write(6,*) ' '
      write(6,912) stp2,ss0
cc      write(6,907) hs0 ,wlen0,umax
      write(*,*) ' ===================================================='

c- "calculate seasickness-factor
c     If the change of acceleration per second exceeds 0.1*g, then
c     seasickness begins. If the change is bigger than 0.3, than 100 %.
      sick=hs2*(2*pi/tper2)**3/g
        fcorr=(wind-30.)/(45.-30.)
        if(fcorr.lt.0.) fcorr=0.
        sick=sick*(1. + fcorr)
      if(tper2.lt.7) sick=sick* (tper2/7.)**2
      slim=0.1
      nsick=100* (sick-slim)/(0.5-slim)
      if(nsick.lt.0) nsick=0
      if(nsick.gt.90) nsick=90
      write(*,*)'   [Sea Sickness Probability=',nsick,' Percent]'

c-  "check for low wind
      if(wind.lt.10.) then
        if(ier.gt.1) write(*,*)'       >>> Warning: critical sea state '
        goto 998
      endif
      
c- "check for shoal and breakers

c   hitting ground
      if(depth .lt. hs2/2.0  .and. ier .lt. 2) then
        write(*,*) '???$#@%?&%##???  YOU JUST STRUCK FLOUNDER !'
        goto 998
      endif
      
c  "shoal waves   and breakers
      if(wlen2 .lt. 1.1  .or.  hs2 .lt. 0.5) goto 111

c  shoal waves
      if(depth .lt. 0.5*wlen2) then
      if(hs2 .gt. 1.0) then
        write(*,*) '    >> WARNING: dangerous shoal waves !'
      else
        write(*,*) '    >>  unpleasant shoal waves !'
      endif
      endif
      
c   breaking waves
      if(ier.eq.0 .and.  stp2 .ge. 0.1) then
        write(*,*) '    >> WARNING: breaking waves ! '
        goto 110
      endif
      if(ier.eq.0 .and.  stp2 .ge. 0.06) then
        write(*,*) '    >> Warning: some breaking waves may appear ! '
      endif

 110  continue
 
c  breakers everywhere
      if(ier.eq.1) then
        write(*,*) ' >>>>> DANGER: HAZARDOUS BREAKERS  !!!!!! '
      endif
      if(ier.ge.2) then
        write(*,*)
     &    ' >>>###>>> DANGER of CAPSIZING: HAZARDOUS BREAKERS !!!!!!!'
       goto 998
      endif

c "development over the next hours <><><><><><><><><><><><><><><><><>

      if(itest.gt.0) goto 998

 111  continue
      write(*,*) ' '
      write(*,*) '          Development over the next hours:'
c
      ieraux=ier
      n=3
      mhrs(1)=3
      mhrs(2)=12
      mhrs(3)=48
      mhrs(4)=6
      mhrs(5)=12
      mhrs(6)=24
      mhrs(7)=48
      nav=3600./tper0
      nav=(nav/10)*10
c
c     "Rayleigh-(Gaussian)-Model for larger wave-heights.
      write(*,*) ' Single waves may reach height=Hmax within  ... hrs:'

      wlena=wlen
      tpera=tper
      durold=dura
      hsalt=0.
c
      do 100 i=1,n
      mr(i)=mhrs(i)*3600./tper0
      if(mr(i).gt.10000) mr(i)=(mr(i)/1000)*1000
      if(mr(i).gt.1000 ) mr(i)=(mr(i)/100 )*100
      if(mr(i).gt.100  ) mr(i)=(mr(i)/10 )*10
      if(mr(1).gt.10000) mr(i)=99999
      if(mr(i).gt.99999) mr(i)=99999
      x=mr(i)
c
c-      projection of hs into future, assuming further growth
      dura=(mhrs(i)+durold)
c
c--------"repeat analysis from above"---------------------------

c- "deep water analysis without current
      call deepw(wind,dura,fetch,hsinf,ht0,hf0,hs00,tper00,wlen00)
      hs0=hs00
      tper0=tper00
      wlen0=wlen00

c- "correction of wave-height and length for current in deep water"
      winc=abs(wind-curr)
      call deepw(winc,dura,fetch,hsinfc,ht0c,hf0c,hs0c,tper0c,wlen0c)
c     now this waveheight  hs0c corresponds to the relative wind in
c     deep water, and also the frequency tper0c    "<NOT USED>

c "evaluation of wave-height and length via dispersion relations
      call curwav(g,depth,curr,tper0,hs0,hs2,wlen2,brk,ier)

c-----------"end analysis from above"----------------------------


      if(model.eq.0) then
       hs2=hs0c
       wlen2=wlen0c
       tper2=tper0c
      else
       tper2=tper0
      endif

c- "steepness
      stp0= hs0 /wlen0
      stp2= hs2 /wlen2
      ss0=stp2/stp0

      hs=hs2
      wlen=wlen2
c
c- "calculate  Hmax via approx. formula: Hmax=Hc*sqrt( ln(M)/2 )
c  "(see also: JONSWAP- and Pierson-Moskowitz-models).
      if(hs.gt.40.) hs=999999.
      if(hs.lt.hsalt)hs=hsalt
      hec(i)=hs
      hsalt=hs
c-    " maximum height from rayleigh-distribution
      hmax=hs*sqrt(alog(x))/sqrt(2.)
      if(hmax.lt.hs) hmax=hs
      if(hmax.gt.30.) hmax=30
      if(hmax.gt.2*deep) hmax=2*deep
      q=hmax/hs
      hem(i)=hmax
      hec(i)=hs
      rat(i)=q
      iseas(i)=3.*hec(i)**0.41+0.2
      if(iseas(i).gt.9) iseas(i)=9
      if(ieraux.gt.1) then
      hem(i)=99999
      hec(i)=99999
      rat(i)=99999
      iseas(i)=9999999
      endif
 100  continue
      write(6,925) (mhrs(i),i=1,n)
c     write(6,921) (mr(i),  i=1,n)
c     write(6,922) (hec(i), i=1,n)
      write(6,923) (hem(i), i=1,n)
c     write(6,924) (rat(i), i=1,n)
      write(6,926) (iseas(i), i=1,n)
      write(*,*) ' [average number of waves per hour:',nav,' ]'
 998  continue

      write(*,*)' ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ '
      write(*,*) ' hit [ENTER] to continue :'
      xcar='-'
      read(5,'(a)') xcar
      do 20 i=1,50
      write(*,*)
 20   continue
      if(xcar.eq.'0') goto 999
      if(xcar.eq.'x') goto 999
      if(xcar.ne.'q') goto 1
 999  write(*,*)' ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ '
      write(*,*) ' '
      write(*,*) '#### end of program oceanwaves ###'
      return
c
 901  format(' n=',i6,' Hmax=',f5.1,' Hmax/Hc=',f5.1,' after',i3,'-hrs')
 902  format('    [deep water  : Hc=',f4.1,' m, Lc=',f4.0,'m]')
 903  format(' shoal eff.: Hc=',f4.1,' m, Lc=',f5.0,'m, Tc=',
     &                       f4.1,' sec  <shallow water>')
 904  format('        Hc=',f4.1,' m,  Lc=',f5.0,'m,  Tc=',f4.1,' sec')
 905  format(1x,i6,' ',2f5.1,'    ',f5.1,'     ',i3,' hrs')
 906  format(' curr. eff.: Hc=',f4.1,' m, Lc=',f5.0,'m, Tc=',
     &                       f4.1,' sec')
 907  format('    [deep water  : Hc=',f4.1,' m, Lc=',f4.0,'m,',
     &' U^=',f5.1,' kt]' )
 910  format('    ==>            Hc=',f4.1,' m, Lc=',f4.0,'m, Tc=',
     &                       f4.1,' sec ')
 911  format(1x,i4,'  ',f5.1,' kt  ',f5.0,'h',f7.0,'km',
     &                  f7.0,'m',f7.1,' kt')
 912  format('    [actual steepness=',f6.3,', factor =',f4.1,']:')
 921  format(1x,' n=      ',10i6)
 922  format(1x,' Hc=     ',10f6.1)
 923  format(10x,' Hmax=   ',10f6.1)
 924  format(1x,' Hmax/Hc=',10f6.1)
 925  format(10x,' hrs=  '  ,10i6)
 926  format(10x,' Seascale=',i3,10i6)
      end
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine deepw(wind,dura,fetch,hsinf,ht0,hf0,hs0,tper0,wlen0)
c- deep-water analysis for waves controlled by wind, fetch and time
      common /com2/ velo,gg,deep
c
c-    "waveheight asymptotically
      hsinf=0.0059*wind**2
c-    "amplitude for time-controlled waveheight
      pt=1.44
      ht0=0.008*wind**pt
c-    "amplitude for fetch-controlled waveheight
      pf=1.15
      hf0=0.0089*wind**pf
c-    "waveheight purely time-controlled
      ptc=0.57
      ht1=ht0*dura**ptc
c-    "waveheight purely fetch-controlled
      pfc=0.44
      hf1=hf0*fetch**pfc
c-    "time and fetch waveheights limited by hsinf
      ph=1.7
      ht=hsinf* tanh((ht1/hsinf)**ph)**(1./ph)
      hf=hsinf* tanh((hf1/hsinf)**ph)**(1./ph)
c
c-    "resulting waveheight
      hs=amin1(ht,hf)
      hs0=hs

c-    "waveperiod:" We use the following formulas for developed windsea:
c     t0=0.31*wind =~ (2Pi/g)*(1852/3600.)*wind;  hs=0.006 * wind^2;
c     The fetch and time-limitation are incorporated by assuming that
c     the actual heights "hs" contain this information. So, we compute
c     backward the theoretical wind speed "windt", which would lead to
c     waveheight "hs" in free water, and from that the "waveperiod".
      winde=wind
      hse=hs
      windt=(hse/0.006)**0.5
      ttheo=0.31*windt
c     correction for strong winds dt
      dt0=(winde-windt)/9.0
      dt=dt0
      if(dt0.gt.2) dt=2.+(dt0-2.)/5.
      teff=ttheo-dt
      tper0=teff
      if(tper0.lt.1.) tper0=1.
c-     "Wellenlaenge
      wlen0=1.56*tper0**2
cc      write(*,*) ht1,hf1,hs,tper0,wlen0

      return
      end
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine kdisper(omeg,ak,v1,v2,dv)
c  dispersion-relation for wavenumber ak and ang_frequency omeg
c         omeg-ak*velo=sqrt(g*ak*tanh(ak*depth))
c          (everything in m, sec)
      common /com2/ velo,g,depth
c "dispersion relation: v1=v2; there is no solution for u>u^, in
c "deep water: u^=-g/(4 omeg), shallow water: u^=sqrt(g depth).
      v1= omeg-ak*velo
      v2= sqrt(g*ak*tanh(ak*depth))
      dv=v2-v1
      return
      end
cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine wvnum(ak,grav,tper0,curr,depth,ier)
      common /com2/ velo,g,deep
c "evaluation of wavenumber  ak  from dispersion relation
c     " (only the smaller wavenumber is used for ak)
c     " (if no solution: akmin used instead)
      pi=3.1415927
      qktms=1852./3600.
      omeg=2*pi/tper0
      g=grav
      deep=depth
      velo=curr* qktms
c     "definition of velocities:
c       v1c,v2c=critical velocities
c       v1c= g/(4.*omeg) for deep water
c       v2c= sqrt(g*depth)  for shallow water
c
      rmin=9999.9
      restx=rmin
      resty=rmin
      akmin=2*pi
      akx=-1.
      nz=10000
      mz=nz/10
      wlmx=2100.
      dw=wlmx/(nz+1)
      ier=2

c
      do 10 i=1,nz
      wl=dw*i
      if(wl.lt.1.) wl=1.
      ak=2*pi/wl
      call kdisper(omeg,ak,v1,v2,rest)

c     "find place of sign change
      if(i.eq.1) restx=rest
      if(rest*restx.le.0) then
        akx=ak
      endif
      restx=rest

c     "find minimum distance
      if(abs(rest).lt.rmin) then
        rmin=abs(rest)
        akmin=ak
      endif

c      "check for sign change, to identify crossing of curves
      is=1
      if(rest.lt.0.) is=-1
      if(i.eq.1) isold=is
      if(isold.ne.is) ier=0
      isold=is

cc       if((i/mz)*mz.eq.i) write(*,*) i,ak,wl,rest,rmin
cc       if(i.gt.nz-10)  write(*,*) i,ak,rest,rmin
 10   continue

      ak=akx
      if(ak.le.0) ak=akmin
      if(ier.ne.0) ak=akmin
cc      write(*,*) '# i,akx,akmin,ak,rmin' , i,akx,akmin,ak,rmin
      return
      end

ccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine heicor
     &(g,depth0,depth,curr0,curr,tper0,ak0,ak,he0,he2,ier)
c "produces waveheight  he2  considering current and depth.
c "correcting the wave-height for the current, following technical note
c "CETN IV-9,  by Jane McKee Smith
c "US Army Coastal Engineering Research Center, address
c "3090 Halls Ferry Road, Vicksburg, Mississippi
      common /com2/ velo,gg,deep
      pi=3.1415927
      velo=curr*1852./3600.
      wavel=2*pi/ak
c
      ttan0=tanh(ak0*depth0)
      omegr0=sqrt(g*ak0*ttan0)
      omeg0=omegr0
c
      ttan=tanh(ak*depth)
      omegr2=sqrt(g*ak*ttan)

c     "check for 'supersonics', steepness then is fixed to stmax
      if(ier.ne.0) then
       stmax=0.999
       brk=1.
       he2=stmax* 2*pi/ak
       goto 601
      endif
      
c     "calculate  he2 from current going against inflowing waves
      vp0  =omegr0/ak0
      vpr0=vp0
      vpr2  =omegr2/ak
      vp2=vpr2+velo
      vgr0 =0.5*(g*ttan0+g*ak0*(1.-ttan0**2)*depth0)/sqrt(g*ak0*ttan0)
      vg0=vgr0
      vgr2  =0.5*(g*ttan +g*ak *(1.-ttan **2)*depth )/sqrt(g*ak *ttan )
      vg2=vgr2+velo
      cgr2=0.5*(omegr2/ak)*(1.+2*ak*depth/sinh(2*ak*depth))
      if(abs(vgr2-cgr2) .gt.0.01) write(*,*) 'ERROR: v,c=',vgr2,cgr2
      he2=he0*sqrt((vgr0/omegr0)*(omegr2/vg2))
      brk=he2/(wavel*ttan)
 601  continue
c     "arbitrary limitation

c     "check for breakers
      bc1=0.14
      bc2=0.88*depth/(wavel*ttan)
      if(brk.gt.bc1 .or.  brk.gt.bc2) ier=ier+1
      if(ier.gt.1) he2=9999.99
      if(he2.gt.5*he0) he2=9999.99
      return
      end
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine curwav(g,depth,curr,tper0,hs0,hs2,wlen2,brk,ier)
c "evaluate the new wave-height and the wave-length over the shoal
c "including current,  via the conservation of wave-action,
c "using the dispersion-relation of shallow water + current versus
c "the dispersion relation of deep water without current
      common /com2/ velo,gg,deep
cc      write(*,*) '%%%%%%%%%%%%%%%%%%%% here i start sr curwav  %%%'
      pi=3.1415927
      gg=g
c- "dispersion relation for wave-number ak0, deep+ no current
c
      curr0=0.
      depth0=5000.
      call wvnum(ak0,g,tper0,curr0,depth0,ier)
         wlen0= 2*pi/ak0
cc      write(*,*) ' curwav>        wlen0',wlen0

c- "dispersion relation for wave-number ak, shallow depth+current
c
      call wvnum(ak ,g,tper0,curr ,depth ,ier)

c- "correction of waveheight for current [CETN-IV-9 (6/97) J.M.Smith]
      he0=hs0
      call heicor(g,depth0,depth,curr0,curr,tper0,ak0,ak ,he0,he2,ier)
      hs2=he2
      if(ak.gt.1.) ak=1.
      if(ak.lt.1./2000.) ak=1./2000.
      wlen2=2*pi/ak

cc      write(*,*) '%%%%%%%%%%%%%%%%%%%%%%% here i end sr curwav  %%%'
      return
      end
cccccccccccccccccccccccccccccccc
      subroutine myname(day,month,year)
      real month
      character xcar
      md=day
      mm=month
      my=year
      if(md.eq.20.and.mm.eq.4.and.my.eq.1944) then
      write(*,*) '                     COPYRIGHT :'
      write(*,*) '          <author: Heiner Mueller-Krumbhaar>'
      write(*,*) '     <address: Poststr.5, D-40789 Monheim, Germany>'
      write(*,*)
      write(*,*) '         ------  hit [ENTER] to continue :'
      xcar='-'
      read(5,'(a)') xcar
      endif
      do 10 i=1,20
      write(*,*)
  10  continue
      return
      end
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      subroutine swell()
c"  ~~~~~~~~~~~~~~~          SWELL   ~~~~~~~~~~~~~~~<hmk>
c "ocean-swell: given its period and height, the program
c "gives an estimate for the originating windspeed and the
c "distance of the orgiginating wind-field
      character*1 xcar

 1    continue
      do 998 i=1,50
      write(*,*)
  998 continue
      write(*,*)
      write(*,*)
     & ' ~~~~~~~~~~~~~~~~~  S W E L L ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ '
      write(*,*)
      write(*,*)
     & 'From the observation of the swell height and swell period,'
      write(*,*)
     & 'this program calculates the strength or speed and the distance'
      write(*,*)
     & 'of the windfield which has caused the observed swell.'
      write(*,*)
      write(*,*) '[enter  0   to return to main menu]'
      write(*,*)
      write(*,*) 'Input: Period of the swell in seconds'
      if(s.le.0) return
      read(*,*)   s0
      write(*,*)
      if(s0.lt.0.1) return
      write(*,*) 'Input: Height of the swell in meters='
      read(*,*)   h0

      period=s0
      height=h0
      call swelld(period,height,wind,dist,ier)
      ibft=0.726*wind**0.665 +0.5
      if(dist.gt.10  ) dist=(int(dist)/10)*10
      if(dist.gt.100 ) dist=(int(dist)/50)*50
      if(dist.gt.1000) dist=(int(dist)/100)*100
      write(*,*)
      do 997 i=1,50
      write(*,*)
  997 continue
      write(*,*)
     & ' ~~~~~~~~~~~~~~~~~  S W E L L ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ '
      write(*,*)
      write(*,*)
      write(6,901) period,height
      write(*,*)
      write(*,*) '   This leads to the following conclusion:'
      write(*,*)
      if(ier.eq.0) then
       write(*,*) 'The (distant) Wind-Field is characterized by:'
       write(*,*)
       write(6,902) wind,ibft,dist
      else
       if(ier.eq.1) then
        write(6,921) wind, ibft
        write(*,*)
        write(6,922) dist
        write(*,*)
       endif
       if(ier.eq.2) then
        write(6,931) wind, ibft
        write(*,*)
        write(6,932) dist
        write(*,*)
       endif
      endif
      write(*,*)
      write(*,*)
      write(*,*)
      write(*,*)
      write(*,*)
      write(*,*)
      write(*,*) 'hit [ENTER] to continue'
      xcar='-'
      read(5,'(a)') xcar
      if(0.eq.0) goto 1
      stop
 901  format(' Period of the Swell =',f6.1,' sec,  Height =',f4.1,' m')
 902  format(' Windspeed =',f4.0,' kt, Bft=',i3,
     &';   Distance =',f6.0,' km')
 921  format(' Windspeed less than =',f4.0,' kt, Bft=',i3)
 922  format(' Distance of Windfield larger than =', f6.0,' km')
 931  format(' Windspeed higher than =',f4.0,' kt, Bft=',i3)
 932  format(' Distance of Windfield less than =', f6.0,' km')

      end
cccccccccc"       SWELLD
      subroutine swelld(period,height,wind,dist,ier)
c "ocean-swell: given its period and height, the program
c "gives an estimate for the originating windspeed and the
c "distance of the orgiginating wind-field
      dimension a(10),nw(10),dt(10),tzero(10)
      external dista, hswell
c     nw(2)=30 knots wind speed, a(2) amplitude height dep.on period
c     "This interpolates the Abb.21.8 from Seewetter-Book
      nw(1)=20
      nw(2)=30
      nw(3)=40
      nw(4)=50
c
      s0=period
      h0=height
      s=s0

c
      ier=0
      smin=6.
      hmin= hswell(s,1)
      hmax= hswell(s,4)
      if(h0.lt.hmin) then
       ier=1
       wind=nw(1)
       dist=dista(s,1)
       goto 999
      endif
      if(h0.gt.hmax) then
       ier=2
       wind=nw(4)
       dist=dista(s,4)
       goto 999
      endif

      do 10 i=1,4
      if(s.gt.tzero(i)) then
       dist=dista(s,i)
      else
       dist=0.
      endif
      h= hswell(s,i)
 10   continue

c    "determine wind-speed
      ilow=0
      ihig=0
      do 100 i=1,4
       h= hswell(s,i)
      if(h0.gt.h) ilow=i
 100  continue
      ihig=ilow+1

c     "interpolation for wind-speed and distance, from height
      h1= hswell(s,ilow)
      h2= hswell(s,ihig)
      g1=(h2-h0)/(h2-h1)
      g2=(h0-h1)/(h2-h1)
      wind=nw(ilow)*g1+nw(ihig)*g2
      d1=dista(s,ilow)
      d2=dista(s,ihig)
      dist=d1*g1+d2*g2

 999  continue
      return
      end
cccccccccccccccccccccccccccccccccc
      function dista(s,i)
      dimension tzero(10)
      tzero(1)=7.0
      tzero(2)=8.5
      tzero(3)=9.2
      tzero(4)=9.6
      if(s.lt.tzero(i)) s=tzero(i)
      dista=280*(s-tzero(i))**1.236
      return
      end
ccccccccccccccccccccccccccccccccc
      function hswell(s,i)
      dimension a(10)
      a(1)=436
      a(2)=1403
      a(3)=3443
      a(4)=5673
      hswell=a(i)* s**(-2.7)
      return
      end
ccccccccccccccccccccccccccccccccc
      subroutine readit(xxx)
      character*8 aaa,bbb
      bbb=''
      aaa='abcdefgh'
      write(6,901) xxx
      read(5,'(a)') aaa
      write(*,*) aaa
      if(aaa.eq.bbb) return
      read(aaa,*) xxx
      if(xxx.gt.  999999.) xxx= 999999.
      if(xxx.lt. -999999.) xxx=-999999.
      return
 901  format('        [ Default: ',f10.1,' ].    Input=')
      end
c~~~~~~~~~~~~~end-of-program~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      
